@@ -408,10 +408,10 @@ summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvide
   table_segment(nc, " frames", "│");
   table_segment(nc, "output(B)", "│");
   table_segment(nc, "rendering", "│");
+  table_segment(nc, "    FPS", "│");
   table_segment(nc, "%r", "│");
   table_segment(nc, "%w", "│");
-  table_segment(nc, "    FPS", "│");
-  table_segment(nc, "TheoFPS", "║\n══╤════════╤════════╪═══════╪═════════╪═════════╪══╪══╪═══════╪═══════╣\n");
+  table_segment(nc, "TheoFPS", "║\n══╤════════╤════════╪═══════╪═════════╪═════════╪═══════╪══╪══╪═══════╣\n");
   char timebuf[PREFIXSTRLEN + 1];
   char tfpsbuf[PREFIXSTRLEN + 1];
   char totalbuf[BPREFIXSTRLEN + 1];
@@ -423,7 +423,8 @@ summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvide
     qprefix(results[i].stats.render_ns, GIG, rtimebuf, 0);
     bprefix(results[i].stats.render_bytes, 1, totalbuf, 0);
     if(results[i].stats.renders){
-      qprefix((uintmax_t)results[i].stats.renders * GIG * 1000 / results[i].stats.render_ns,
+      qprefix((uintmax_t)results[i].stats.renders * GIG * 1000 /
+              (results[i].stats.render_ns + results[i].stats.writeout_ns),
               1000, tfpsbuf, 0);
     }else{
       qprefix(0, GIG, tfpsbuf, 0);
@@ -445,15 +446,15 @@ summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvide
     ncdirect_fg_rgb(nc, rescolor);
     printf("%8s", demos[results[i].selector - 'a'].name);
     ncdirect_fg_rgb8(nc, 178, 102, 255);
-    printf("│%*ss│%7ju│%*s│ %*ss│%2jd│%2jd│%7.1f│%*s║",
+    printf("│%*ss│%7ju│%*s│ %*ss│%7.1f│%2jd│%2jd│%*s║",
            PREFIXFMT(timebuf), (uintmax_t)(results[i].stats.renders),
            BPREFIXFMT(totalbuf), PREFIXFMT(rtimebuf),
+           results[i].timens ?
+            results[i].stats.renders / ((double)results[i].timens / GIG) : 0.0,
            (uintmax_t)(results[i].timens ?
             results[i].stats.render_ns * 100 / results[i].timens : 0),
            (uintmax_t)(results[i].timens ?
             results[i].stats.writeout_ns * 100 / results[i].timens : 0),
-           results[i].timens ?
-            results[i].stats.renders / ((double)results[i].timens / GIG) : 0.0,
            PREFIXFMT(tfpsbuf));
     ncdirect_fg_rgb(nc, rescolor);
     printf("%s\n", results[i].result < 0 ? "FAILED" :
@@ -470,14 +471,12 @@ summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvide
   qprefix(nsdelta, GIG, timebuf, 0);
   bprefix(totalbytes, 1, totalbuf, 0);
   qprefix(totalrenderns, GIG, rtimebuf, 0);
-  table_segment(nc, "", "══╧════════╧════════╪═══════╪═════════╪═════════╪══╪══╪═══════╪═══════╝\n");
+  table_segment(nc, "", "══╧════════╧════════╪═══════╪═════════╪═════════╪═══════╪══╧══╧═══════╝\n");
   printf("            ");
   table_printf(nc, "│", "%*ss", PREFIXFMT(timebuf));
   table_printf(nc, "│", "%7lu", totalframes);
   table_printf(nc, "│", "%*s", BPREFIXFMT(totalbuf));
   table_printf(nc, "│", " %*ss", PREFIXFMT(rtimebuf));
-  table_printf(nc, "│", "%2ld", nsdelta ? totalrenderns * 100 / nsdelta : 0);
-  table_printf(nc, "│", "%2ld", nsdelta ? totalwriteoutns * 100 / nsdelta : 0);
   table_printf(nc, "│", "%7.1f", nsdelta ? totalframes / ((double)nsdelta / GIG) : 0);
   printf("\n");
   ncdirect_fg_rgb8(nc, 0xff, 0xb0, 0xb0);
