@@ -114,7 +114,7 @@ zoom_map(struct notcurses* nc, const char* map, int* ret){
 
 static int
 draw_eagle(struct ncplane* n, const char* sprite){
-  cell bgc = CELL_TRIVIAL_INITIALIZER;
+  nccell bgc = CELL_TRIVIAL_INITIALIZER;
   cell_set_fg_alpha(&bgc, CELL_ALPHA_TRANSPARENT);
   cell_set_bg_alpha(&bgc, CELL_ALPHA_TRANSPARENT);
   ncplane_set_base_cell(n, &bgc);
