@@ -221,6 +221,13 @@ typedef struct ncmenu {
   bool bottom;              // are we on the bottom (vs top)?
 } ncmenu;
 
+typedef struct ncprogbar {
+  ncplane* ncp;
+  double progress;          // on the range [0, 1]
+  uint32_t ulchannel, urchannel, blchannel, brchannel;
+  bool retrograde;
+} ncprogbar;
+
 // terminfo cache
 typedef struct tinfo {
   unsigned colors;// number of colors terminfo reported usable for this screen
@@ -943,7 +950,8 @@ egc_rtl(const char* egc, int* bytes){
     return NULL;
   }
   const int bidic = uc_bidi_category(w);
-  if(bidic != UC_BIDI_R && bidic != UC_BIDI_RLE && bidic != UC_BIDI_RLO){
+//fprintf(stderr, "BIDI CAT (%lc): %d\n", w, bidic);
+  if(bidic != UC_BIDI_R && bidic != UC_BIDI_AL && bidic != UC_BIDI_RLE && bidic != UC_BIDI_RLO){
     return NULL;
   }
   // insert U+200E, "LEFT-TO-RIGHT MARK". This ought reset the text direction
@@ -1061,6 +1069,17 @@ int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp);
 // FIXME absorb into ncinputlayer_init()
 int cbreak_mode(int ttyfd, const struct termios* tpreserved);
 
+// Given the four channels arguments, verify that:
+//
+// - if any is default foreground, all are default foreground
+// - if any is default background, all are default background
+// - all foregrounds must have the same alpha
+// - all backgrounds must have the same alpha
+// - palette-indexed color must not be used
+//
+// If you only want to check n < 4 channels, just duplicate one.
+bool check_gradient_args(uint64_t ul, uint64_t ur, uint64_t bl, uint64_t br);
+
 #ifdef __cplusplus
 }
 #endif
