@@ -570,6 +570,10 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
     logerror(ncplane_notcurses(n), "Can't retain negative size %dx%d\n", keepleny, keeplenx);
     return -1;
   }
+  if(keepy < 0 || keepx < 0){ // can't start at negative origin
+    logerror(ncplane_notcurses(n), "Can't retain negative offset %dx%d\n", keepy, keepx);
+    return -1;
+  }
   if((!keepleny && keeplenx) || (keepleny && !keeplenx)){ // both must be 0
     logerror(ncplane_notcurses(n), "Can't retain null dimension %dx%d\n", keepleny, keeplenx);
     return -1;
@@ -591,6 +595,14 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
   }
   int rows, cols;
   ncplane_dim_yx(n, &rows, &cols);
+  if(keepleny + keepy > rows){
+    logerror(ncplane_notcurses(n), "Can't keep %d@%d rows from %d\n", keepleny, keepy, rows);
+    return -1;
+  }
+  if(keeplenx + keepx > cols){
+    logerror(ncplane_notcurses(n), "Can't keep %d@%d cols from %d\n", keeplenx, keepx, cols);
+    return -1;
+  }
   loginfo(ncplane_notcurses(n), "%dx%d @ %d/%d → %d/%d @ %d/%d (keeping %dx%d from %d/%d)\n", rows, cols, n->absy, n->absx, ylen, xlen, n->absy + keepy + yoff, n->absx + keepx + xoff, keepleny, keeplenx, keepy, keepx);
   // we're good to resize. we'll need alloc up a new framebuffer, and copy in
   // those elements we're retaining, zeroing out the rest. alternatively, if
@@ -934,6 +946,12 @@ get_tty_fd(notcurses* nc, FILE* ttyfp){
     fd = open("/dev/tty", O_RDWR | O_CLOEXEC);
     if(fd < 0){
       loginfo(nc, "Error opening /dev/tty (%s)\n", strerror(errno));
+    }else{
+      if(!isatty(fd)){
+        loginfo(nc, "File descriptor for /dev/tty (%d) is not actually a TTY\n", fd);
+        close(fd);
+        fd = -1;
+      }
     }
   }
   return fd;
@@ -2240,21 +2258,27 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   }
   if(n->blist){
     if(n->boundto == n){ // children become new root planes
+      ncplane* lastlink;
       for(ncplane* child = n->blist ; child ; child = child->bnext){
         child->boundto = child;
-      }
-      if( (n->blist->bnext = ncplane_pile(n)->roots) ){
-        n->blist->bnext->bprev = &n->blist->bnext;
+        lastlink = child;
+      } // n->blist != NULL -> lastlink != NULL
+      if( (lastlink->bnext = ncplane_pile(n)->roots) ){
+        lastlink->bnext->bprev = &lastlink->bnext;
       }
       n->blist->bprev = &ncplane_pile(n)->roots;
       ncplane_pile(n)->roots = n->blist;
     }else{ // children are rebound to current parent
-      ncplane** plink = &n->boundto->blist;
-      while(*plink){
-        plink = &(*plink)->bnext;
+      ncplane* lastlink;
+      for(ncplane* child = n->blist ; child ; child = child->bnext){
+        child->boundto = n->boundto;
+        lastlink = child;
+      } // n->blist != NULL -> lastlink != NULL
+      if( (lastlink->bnext = n->boundto->blist) ){
+        lastlink->bnext->bprev = &lastlink->bnext;
       }
-      n->blist->bprev = plink;
-      *plink = n->blist;
+      n->blist->bprev = &n->boundto->blist;
+      n->boundto->blist = n->blist;
     }
     n->blist = NULL;
   }
