@@ -6,10 +6,11 @@
 #include "internal.h"
 
 // Check whether the terminal geometry has changed, and if so, copies what can
-// be copied from the old stdplane. Assumes that the screen is always anchored at
-// the same origin. Also syncs up lastframe.
+// be copied from the old lastframe. Assumes that the screen is always anchored
+// at the same origin.
 static int
-notcurses_resize_internal(notcurses* n, int* restrict rows, int* restrict cols){
+notcurses_resize_internal(ncplane* pp, int* restrict rows, int* restrict cols){
+  notcurses* n = ncplane_notcurses(pp);
   int r, c;
   if(rows == NULL){
     rows = &r;
@@ -17,14 +18,14 @@ notcurses_resize_internal(notcurses* n, int* restrict rows, int* restrict cols){
   if(cols == NULL){
     cols = &c;
   }
-  int oldrows = n->stdplane->leny;
-  int oldcols = n->stdplane->lenx;
+  ncpile* pile = ncplane_pile(pp);
+  int oldrows = pile->dimy;
+  int oldcols = pile->dimx;
   *rows = oldrows;
   *cols = oldcols;
   if(update_term_dimensions(n->ttyfd, rows, cols)){
     return -1;
   }
-  n->truecols = *cols;
   *rows -= n->margin_t + n->margin_b;
   if(*rows <= 0){
     *rows = 1;
@@ -37,7 +38,7 @@ notcurses_resize_internal(notcurses* n, int* restrict rows, int* restrict cols){
     n->lfdimy = *rows;
     n->lfdimx = *cols;
     const size_t size = sizeof(*n->lastframe) * (n->lfdimy * n->lfdimx);
-    cell* fb = realloc(n->lastframe, size);
+    nccell* fb = realloc(n->lastframe, size);
     if(fb == NULL){
       return -1;
     }
@@ -47,27 +48,26 @@ notcurses_resize_internal(notcurses* n, int* restrict rows, int* restrict cols){
     memset(n->lastframe, 0, size);
     egcpool_dump(&n->pool);
   }
+//fprintf(stderr, "r: %d or: %d c: %d oc: %d\n", *rows, oldrows, *cols, oldcols);
   if(*rows == oldrows && *cols == oldcols){
     return 0; // no change
   }
-  int keepy = *rows;
-  if(keepy > oldrows){
-    keepy = oldrows;
+  pile->dimy = *rows;
+  pile->dimx = *cols;
+  int ret = 0;
+//notcurses_debug(n, stderr);
+  for(ncplane* rootn = pile->roots ; rootn ; rootn = rootn->bnext){
+    if(rootn->resizecb){
+      ret |= rootn->resizecb(rootn);
+    }
   }
-  int keepx = *cols;
-  if(keepx > oldcols){
-    keepx = oldcols;
-  }
-  if(ncplane_resize_internal(n->stdplane, 0, 0, keepy, keepx, 0, 0, *rows, *cols)){
-    return -1;
-  }
-  return 0;
+  return ret;
 }
 
 static int
 notcurses_resize(notcurses* n, int* restrict rows, int* restrict cols){
   pthread_mutex_lock(&n->pilelock);
-  int ret = notcurses_resize_internal(n, rows, cols);
+  int ret = notcurses_resize_internal(notcurses_stdplane(n), rows, cols);
   pthread_mutex_unlock(&n->pilelock);
   return ret;
 }
@@ -147,12 +147,12 @@ update_render_stats(const struct timespec* time1, const struct timespec* time0,
   }
 }
 
-void cell_release(ncplane* n, cell* c){
+void cell_release(ncplane* n, nccell* c){
   pool_release(&n->pool, c);
 }
 
 // Duplicate one cell onto another when they share a plane. Convenience wrapper.
-int cell_duplicate(ncplane* n, cell* targ, const cell* c){
+int cell_duplicate(ncplane* n, nccell* targ, const nccell* c){
   if(cell_duplicate_far(&n->pool, targ, n, c) < 0){
     logerror(ncplane_notcurses(n), "Failed duplicating cell");
     return -1;
@@ -164,7 +164,7 @@ int cell_duplicate(ncplane* n, cell* targ, const cell* c){
 // crender per rendered cell, and they are initialized to all zeroes.
 struct crender {
   const ncplane *p; // source of glyph for this cell
-  cell c;
+  nccell c;
   unsigned fgblends;
   unsigned bgblends;
   // we'll need recalculate the foreground relative to the solved background,
@@ -254,11 +254,11 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
         break;
       }
       struct crender* crender = &rvec[fbcellidx(absy, dstlenx, absx)];
-      cell* targc = &crender->c;
+      nccell* targc = &crender->c;
       if(cell_wide_right_p(targc)){
         continue;
       }
-      const cell* vis = &p->fb[nfbcellidx(p, y, x)];
+      const nccell* vis = &p->fb[nfbcellidx(p, y, x)];
       // if we never loaded any content into the cell (or obliterated it by
       // writing in a zero), use the plane's base cell.
       if(vis->gcluster == 0 && !cell_double_wide_p(vis)){
@@ -286,14 +286,17 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
             }else{
               cell_set_wide(targc);
               targc->stylemask = vis->stylemask;
+              targc->width = vis->width;
             }
           }else{
             targc->stylemask = vis->stylemask;
+            targc->width = vis->width;
           }
           crender->p = p;
         }else if(cell_wide_right_p(vis)){
           cell_set_wide(targc);
           crender->p = p;
+          targc->width = vis->width;
         }
       }
 
@@ -360,7 +363,7 @@ init_rvec(struct crender* rvec, int totalcells){
 // should be done at the end of rendering the cell, so that contrast is solved
 // against the real background.
 static inline void
-lock_in_highcontrast(cell* targc, struct crender* crender){
+lock_in_highcontrast(nccell* targc, struct crender* crender){
   if(cell_fg_alpha(targc) == CELL_ALPHA_TRANSPARENT){
     cell_set_fg_default(targc);
   }
@@ -388,13 +391,13 @@ lock_in_highcontrast(cell* targc, struct crender* crender){
 // wide glyph to its left. FIXME why can't we do this as we go along? FIXME can
 // we not do the blend a single time here, if we track sums in paint()?
 static void
-postpaint(cell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* pool){
+postpaint(nccell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool* pool){
   for(int y = 0 ; y < dimy ; ++y){
     for(int x = 0 ; x < dimx ; ++x){
       struct crender* crender = &rvec[fbcellidx(y, dimx, x)];
-      cell* targc = &crender->c;
+      nccell* targc = &crender->c;
       lock_in_highcontrast(targc, crender);
-      cell* prevcell = &lastframe[fbcellidx(y, dimx, x)];
+      nccell* prevcell = &lastframe[fbcellidx(y, dimx, x)];
       if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
         crender->damaged = true;
         if(cell_wide_left_p(targc)){
@@ -443,7 +446,7 @@ int ncplane_mergedown(const ncplane* restrict src, ncplane* restrict dst,
     return -1;
   }
   const int totalcells = dst->leny * dst->lenx;
-  cell* rendfb = calloc(sizeof(*rendfb), totalcells);
+  nccell* rendfb = calloc(sizeof(*rendfb), totalcells);
   const size_t crenderlen = sizeof(struct crender) * totalcells;
   struct crender* rvec = malloc(crenderlen);
   if(!rendfb || !rvec){
@@ -494,9 +497,9 @@ ncfputc(char c, FILE* out){
 #endif
 }
 
-// write the cell's UTF-8 extended grapheme cluster to the provided FILE*.
+// write the nccell's UTF-8 extended grapheme cluster to the provided FILE*.
 static int
-term_putc(FILE* out, const egcpool* e, const cell* c){
+term_putc(FILE* out, const egcpool* e, const nccell* c){
   if(cell_simple_p(c)){
 //fprintf(stderr, "[%.4s] %08x\n", (const char*)&c->gcluster, c->gcluster); }
     uint32_t firstbyte = htole(c->gcluster) & 0xff;
@@ -542,7 +545,7 @@ int term_setstyle(FILE* out, unsigned cur, unsigned targ, unsigned stylebit,
 
 // write any escape sequences necessary to set the desired style
 static inline int
-term_setstyles(FILE* out, uint32_t* curattr, const cell* c, bool* normalized,
+term_setstyles(FILE* out, uint32_t* curattr, const nccell* c, bool* normalized,
                const char* sgr0, const char* sgr, const char* italics,
                const char* italoff, const char* struck, const char* struckoff){
   *normalized = false;
@@ -601,9 +604,6 @@ static const char* const NUMBERS[] = {
 
 static inline int
 term_esc_rgb(FILE* out, bool foreground, unsigned r, unsigned g, unsigned b){
-  assert(r < 256);
-  assert(g < 256);
-  assert(b < 256);
   // The correct way to do this is using tiparm+tputs, but doing so (at least
   // as of terminfo 6.1.20191019) both emits ~3% more bytes for a run of 'rgb'
   // and gives rise to some inaccurate colors (possibly due to special handling
@@ -778,14 +778,14 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
   // we explicitly move the cursor at the beginning of each output line, so no
   // need to home it expliticly.
   update_palette(nc, out);
-  // FIXME need adapt this to piles
-  for(y = nc->stdplane->absy ; y < nc->stdplane->leny + nc->stdplane->absy ; ++y){
+//fprintf(stderr, "pile %p ymax: %d xmax: %d\n", p, p->dimy + nc->stdplane->absy, p->dimx + nc->stdplane->absx);
+  for(y = nc->stdplane->absy ; y < p->dimy + nc->stdplane->absy ; ++y){
     const int innery = y - nc->stdplane->absy;
-    for(x = nc->stdplane->absx ; x < nc->stdplane->lenx + nc->stdplane->absx ; ++x){
+    for(x = nc->stdplane->absx ; x < p->dimx + nc->stdplane->absx ; ++x){
       const int innerx = x - nc->stdplane->absx;
       const size_t damageidx = innery * nc->lfdimx + innerx;
       unsigned r, g, b, br, bg, bb, palfg, palbg;
-      const cell* srccell = &nc->lastframe[damageidx];
+      const nccell* srccell = &nc->lastframe[damageidx];
       if(!rvec[damageidx].damaged){
         // no need to emit a cell; what we rendered appears to already be
         // here. no updates are performed to elision state nor lastframe.
@@ -908,15 +908,12 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
           nc->rstate.defaultelidable = false;
           nc->rstate.bgpalelidable = false;
         }
-//fprintf(stderr, "RAST %08x [%s] to %d/%d %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->channels);
+//fprintf(stderr, "RAST %08x [%s] to %d/%d cols: %u %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->width + 1, srccell->channels);
         if(term_putc(out, &nc->pool, srccell)){
           return -1;
         }
-        ++nc->rstate.x;
-        if(cell_wide_left_p(srccell)){
-          ++nc->rstate.x;
-          ++x;
-        }
+        nc->rstate.x += srccell->width + 1;
+        x += srccell->width;
       }
 //fprintf(stderr, "damageidx: %ld\n", damageidx);
     }
@@ -1091,34 +1088,41 @@ int ncpile_rasterize(ncplane* n){
   return 0;
 }
 
-// ensure the crender vector of 'n' is sufficiently large for 'dimy'x'dimx'
+// ensure the crender vector of 'n' is sufficiently large for
+// 'n'->dimy x 'n'->dimx, having previously been 'dimy'x'dimx', and initialize
+// the rvec afresh for a new render.
 static int
 engorge_crender_vector(ncpile* n, int dimy, int dimx){
-  const int crenderlen = dimy * dimx;
-  if(crenderlen > n->dimy * n->dimx){
+  const int crenderlen = n->dimy * n->dimx; // desired size
+  if(crenderlen <= 0){
+    return -1;
+  }
+//fprintf(stderr, "crlen: %d y: %d x:%d\n", crenderlen, dimy, dimx);
+  if(crenderlen > dimy * dimx){
     struct crender* tmp = realloc(n->crender, sizeof(*tmp) * crenderlen);
     if(tmp == NULL){
       return -1;
     }
     n->crender = tmp;
-    n->dimy = dimy;
-    n->dimx = dimx;
   }
   init_rvec(n->crender, crenderlen);
   return 0;
 }
 
 int ncpile_render(ncplane* n){
-  notcurses* nc = ncplane_notcurses(n);
-  int dimy, dimx;
-  // update our notion of screen geometry, and render against that
-  notcurses_resize(nc, &dimy, &dimx);
   struct timespec start, renderdone;
   clock_gettime(CLOCK_MONOTONIC, &start);
-  if(engorge_crender_vector(ncplane_pile(n), dimy, dimx)){
+  notcurses* nc = ncplane_notcurses(n);
+  ncpile* pile = ncplane_pile(n);
+  const int olddimy = pile->dimy;
+  const int olddimx = pile->dimx;
+  // update our notion of screen geometry, and render against that
+  notcurses_resize_internal(n, NULL, NULL);
+  if(engorge_crender_vector(pile, olddimy, olddimx)){
     return -1;
   }
-  ncpile_render_internal(n, ncplane_pile(n)->crender, dimy, dimx,
+  // FIXME notcurses_stdplane() doesn't belong here
+  ncpile_render_internal(n, pile->crender, pile->dimy, pile->dimx,
                          notcurses_stdplane(nc)->absy,
                          notcurses_stdplane(nc)->absx);
   clock_gettime(CLOCK_MONOTONIC, &renderdone);
@@ -1158,7 +1162,7 @@ int notcurses_render_to_buffer(notcurses* nc, char** buf, size_t* buflen){
 // copy the UTF8-encoded EGC out of the cell, whether simple or complex. the
 // result is not tied to the ncplane, and persists across erases / destruction.
 static inline char*
-pool_egc_copy(const egcpool* e, const cell* c){
+pool_egc_copy(const egcpool* e, const nccell* c){
   if(cell_simple_p(c)){
     return strdup((const char*)&c->gcluster);
   }
@@ -1170,7 +1174,7 @@ char* notcurses_at_yx(notcurses* nc, int yoff, int xoff, uint16_t* stylemask, ui
   if(nc->lastframe){
     if(yoff >= 0 && yoff < nc->lfdimy){
       if(xoff >= 0 || xoff < nc->lfdimx){
-        const cell* srccell = &nc->lastframe[yoff * nc->lfdimx + xoff];
+        const nccell* srccell = &nc->lastframe[yoff * nc->lfdimx + xoff];
         if(stylemask){
           *stylemask = srccell->stylemask;
         }
